* Stata code for generating Figures and Tables in
* ``Structural change out of Agriculture: Labor Push versus Labor Pull''
* by Francisco Alvarez-Cuadrado and Markus Poschke

use "pushpull_data.dta"

*************************************************
/*                     Figures                 */
*************************************************

/* Figure 1 */
set scheme s2mono
tsline pPPI Lash if code=="USA", graphregion(c(white)) legend(region(style(none)))
graph export UStimeseries_mono.pdf, replace
graph export UStimeseries_mono.eps, replace

/* Figure 2 */
tsline pPPI relTFP if code=="USA", graphregion(c(white)) legend(region(style(none)))
graph export relp_TFP_US_mono.pdf, replace
graph export relp_TFP_US_mono.eps, replace


/* Figure 3 */

* * for countries with disjoint series, create variable with joint series
* by cy: egen firstyearpVA = min(cond(pVAMA5<., year, .))
* gen gpjoint = gpVAMA5
* gen Lajoint = LaMA5
* foreach cy in "BEL" "ESP" "FRA" "GER" "JPN" "KOR" "NLD" "UK" {
* 	gen gp`cy'1 = gpVAMA5 if code=="`cy'1"
* 	gen gp`cy'2 = gpVAMA5 if code=="`cy'2"
* 	gen La`cy'1 = LaMA5 if code=="`cy'1"
* 	gen La`cy'2 = LaMA5 if code=="`cy'2"
* 	sort year
* 	by year: egen gp`cy'1cy = mean(gp`cy'1)
* 	by year: egen gp`cy'2cy = mean(gp`cy'2)
* 	by year: egen La`cy'1cy = mean(La`cy'1)
* 	by year: egen La`cy'2cy = mean(La`cy'2)
* 	gen gp`cy' = min(gp`cy'1cy, gp`cy'2cy)
* 	gen La`cy' = min(La`cy'1cy, La`cy'2cy)
* 	replace gpjoint = gp`cy' if code=="`cy'" 
* 	replace Lajoint = La`cy' if code=="`cy'" 
* 	drop gp`cy'* La`cy'*
* }
* sort cy year
* * order year cy code Lash LaMA5 pVA pVAMA5 gpVAMA5 gpjoint Lajoint

set scheme s2mono
graph drop _all
xtline Lajoint if code=="USA"|code=="CAN"|code=="UK"|code=="UK", i(cy) t(year) overlay legend(rows(2)) ///
legend(r(1) order(2 3 1)) ytitle("") name(La1) ysc(r(0 0.8)) ///
	xsc(r(1800 2000)) xlabel(#5) ylabel(#5) graphregion(c(white)) legend(region(style(none)))
graph export La1.pdf, name(La1) replace
graph export La1.eps, name(La1) replace
xtline Lajoint if code=="NLD"|code=="BEL"|code=="FRA"|code=="GER", i(cy) t(year) overlay legend(rows(2)) ///
legend(r(1) order(2 3  1 4)) ytitle("")  name(La2) ysc(r(0 0.8)) ///
	xsc(r(1800 2000)) xlabel(#5)ylabel(#5) graphregion(c(white)) legend(region(style(none)))
graph export La2.pdf, name(La2) replace
graph export La2.eps, name(La2) replace
xtline Lajoint if code=="JPN"|code=="KOR", i(cy) t(year) overlay legend(rows(2)) ///
legend(r(1) order(2 3 1)) ytitle("") name(La3) ysc(r(0 0.8)) ///
	xsc(r(1800 2000)) xlabel(#5)ylabel(#5) graphregion(c(white)) legend(region(style(none)))
graph export La3.pdf, name(La3) replace
graph export La3.eps, name(La3) replace
xtline Lajoint if code=="FIN"|code=="SWE"|code=="ESP", i(cy) t(year) overlay legend(rows(2)) ///
legend(r(1) order(1 3 2 4 )) ytitle("") name(La4) ysc(r(0 0.8)) ///
	xsc(r(1800 2000)) xlabel(#5)ylabel(#5) graphregion(c(white)) legend(region(style(none)))
graph export La4.pdf, name(La4) replace
graph export La4.eps, name(La4) replace

/* Figure 4 */
* use "pushpull_data.dta", clear
* gen pVAfirst = pVAMA5 if year==firstyearpVA
* by cy: egen pVAfirstcy = mean(pVAfirst)
* gen pVAstd = pVAMA5/pVAfirstcy

set scheme s2mono
xtline pVAstd, i(cy) t(year) overlay legend(off) ytitle("pm/pa") ///
	yscale(log) ylabel(.5 1 2 3 4) graphregion(c(white)) legend(region(style(none)))
graph export pvstimelog.pdf, replace
graph export pvstimelog.eps, replace
* against La:
sort cy year
twoway (line pVAstd LaMA5 if code=="CAN") ///
	(line pVAstd LaMA5 if code=="UK1") (line pVAstd LaMA5 if code=="UK2") ///
    (line pVAstd LaMA5 if code=="NLD1") (line pVAstd LaMA5 if code=="NLD2") ///
	(line pVAstd LaMA5 if code=="BEL1") (line pVAstd LaMA5 if code=="BEL2") ///
	(line pVAstd LaMA5 if code=="FRA1") (line pVAstd LaMA5 if code=="FRA2") ///
	(line pVAstd LaMA5 if code=="GER1") (line pVAstd LaMA5 if code=="GER2") ///
    (line pVAstd LaMA5 if code=="JPN1") (line pVAstd LaMA5 if code=="JPN2") ///
	(line pVAstd LaMA5 if code=="FIN") 	(line pVAstd LaMA5 if code=="KOR1") ///
	(line pVAstd LaMA5 if code=="KOR2") (line pVAstd LaMA5 if code=="SWE") 	///
	(line pVAstd LaMA5 if code=="ESP"), legend(off) ///
   	xtitle("employment share in agriculture") ytitle("pm/pa") ///
   	yscale(log) ylabel(.5 1 2 3 4) graphregion(c(white)) legend(region(style(none)))
graph export pvsLalog.pdf, replace
graph export pvsLalog.eps, replace



*************************************************
/*                     Tables                  */
*************************************************

/* Table 2 */
* using Maddison data available at http://www.ggdc.net/maddison/ 


/* Table 3 */

* * create stage dummies 
* gen La20 = .2*floor(Lajoint/.2)
* replace La20 = .6 if Lajoint>.8 & Lajoint<. 
* * 0-.1999, .2-.3999, ...
* gen LaT = La20
* replace LaT = .1 if Lajoint>=.1&Lajoint<.2
* 
* * create period dummies 
* gen yr40 = 40*floor(year/40)
* replace yr40 = 1800 if yr40==1760 
* replace yr40 = 1960 if yr40==2000 
* * 1789-1839, 1840-79, 1880-1919, 1920-59, 1960-2009

sort code
* gen gp1 = ln(1+gpjoint)
by code: tabstat gp1, by (LaT)
* (exp of the results)-1 is the geometric mean given in the table
by code: tabstat gp1, by(yr40)


/* Table 4 */
* * compute gpright 
* * compute mean gp per country using pVAMA5 observation
* * for first and last year where LaMA5 also available
* by cy: egen lastyearboth = max(cond(LaMA5<.&pVAMA5<., year, .))
* by cy: egen firstyearpforg = min(max(cond(pVAMA5<.&year<firstyearboth, year, .)),firstyearboth)
* gen pfirst = pVAMA5 if year==firstyearpforg
* gen plast = pVAMA5 if year==lastyearboth
* by cy: egen pfirstcy = mean(pfirst)
* by cy: egen plastcy = mean(plast)
* drop pfirst plast
* gen gpratio = plastcy/pfirstcy
* gen gpright = (gpratio)^(1/(lastyearboth-firstyearpforg)) -1
* * where needed, combine two episodes:
* foreach cy in "BEL" "ESP" "FRA" "GER" "JPN" "KOR" "NLD" "UK" {
* 	gen gpratio`cy'1 = gpratio if code=="`cy'1"
* 	gen gpratio`cy'2 = gpratio if code=="`cy'2"
* 	gen length`cy'1 = lastyearboth-firstyearpforg if code=="`cy'1"
* 	gen length`cy'2 = lastyearboth-firstyearpforg if code=="`cy'2"
* 	egen gpratio`cy'1cy = mean(gpratio`cy'1)
* 	egen gpratio`cy'2cy = mean(gpratio`cy'2)
* 	egen length`cy'1cy = mean(length`cy'1)
* 	egen length`cy'2cy = mean(length`cy'2)
* 	gen gpratio`cy'tot = gpratio`cy'1cy*gpratio`cy'2cy
* 	gen length`cy'tot = length`cy'1cy+length`cy'2cy
* 	gen gpright`cy' = gpratio`cy'tot^(1/length`cy'tot)-1
* 	replace gpright = gpright`cy' if code=="`cy'" 
* 	drop gpratio`cy'* gpright`cy' length`cy'*
* }
* drop pfirst* plast* gpratio
* 
* by cy: egen firstyearboth = min(cond(LaMA5<.&pVAMA5<., year, .)) 
* gen pVL = pVAMA5 if disjoint==1& (LaMA5<.|year<firstyearboth)
* gen Lag = LaMA5 if disjoint==1&pVAMA5<.
* gen lnpVL = log(pVL)
* gen lnLag = log(Lag)
* sort cy year
* by cy: ipolate lnpVL year if disjoint==1&year>=firstyearpVA&year<=lastyearpVA, g(lnpVLipol)
* gen gpVL = lnpVLipol-L.lnpVLipol if disjoint==1&pVL<.&LaMA5<.
* gen gpVLj = gpVL
* foreach cy in "BEL" "ESP" "FRA" "GER" "JPN" "KOR" "NLD" "UK" {
* 	gen gp`cy'1 = gpVL if code=="`cy'1"
* 	gen gp`cy'2 = gpVL if code=="`cy'2"
* 	sort year
* 	by year: egen gp`cy'1cy = mean(gp`cy'1)
* 	by year: egen gp`cy'2cy = mean(gp`cy'2)
* 	gen gp`cy' = min(gp`cy'1cy, gp`cy'2cy)
* 	replace gpVLj = gp`cy' if code=="`cy'" 
* 	drop gp`cy'* 
* }

/* regressions */
* when using time series dimension, use gpVLj (growth rates computed
* in years when there's both a price and an L observation)
* when only using between dimension, use gpright (average
* growth rate over the period when both p and L available)

* pooled regressions (column 1)
xi i.LaT i.yr40, noomit
reg gpVLj _ILaT_1 _ILaT_2 _ILaT_3 _ILaT_4 _Iyr40_1800 _Iyr40_1840 _Iyr40_1880 _Iyr40_1920 if joint==1,r cl(cy)
testparm _IL* // sig at 1%
testparm _Iyr* // sig at 1.5%

* fixed effects (column 3)
xtreg gpVLj _ILaT_1 _ILaT_2 _ILaT_3 _ILaT_4 _Iyr40_1800 _Iyr40_1840 _Iyr40_1880 _Iyr40_1920 if joint==1, fe r cl(cy)
testparm _IL* // sig at 1%
testparm _Iyr* // sig at 1%

* between regression (column 2)
reg gpright Lajmean if joint==1&year==1900, r










